[pypy-commit] extradoc extradoc: updated benchmark numbers

Raemi noreply at buildbot.pypy.org
Thu Jul 31 16:02:26 CEST 2014


Author: Remi Meier <remi.meier at inf.ethz.ch>
Branch: extradoc
Changeset: r5382:fc61395ad9ed
Date: 2014-07-31 16:00 +0200
http://bitbucket.org/pypy/extradoc/changeset/fc61395ad9ed/

Log:	updated benchmark numbers

diff --git a/talk/dls2014/paper/plots/performance.pdf b/talk/dls2014/paper/plots/performance.pdf
index de33012fb48dea85ff95c68e3b6b7be60b077835..9c48101801c6fe17a25b0c587435cfbfd80fa636
GIT binary patch

[cut]

diff --git a/talk/dls2014/paper/plots/plot_performance_nojit.py b/talk/dls2014/paper/plots/plot_performance_nojit.py
--- a/talk/dls2014/paper/plots/plot_performance_nojit.py
+++ b/talk/dls2014/paper/plots/plot_performance_nojit.py
@@ -38,21 +38,23 @@
 #    pypy-c-paper-nojit bench.py -k5 threadworms/threadworms.py 1-4 500000
 #    pypy-c-paper-nojit bench.py -k5 mandelbrot/mandelbrot.py 1-4 64 512 512
 #    pypy-c-paper-nojit multithread-richards.py 30 1-4 # report runtime
+# miller_rabin: bench.py -k5 primes/primes.py 1-4 400000
+# mersenne:  bench.py -k5 mersenne/mersenne.py $i 1500
 
 from collections import OrderedDict
 benchs = OrderedDict([
      ("btree (small)", {
         "pypy-stm-nojit":[
-            [8.21,8.10,8.19,8.13,8.14],
-            [4.60,4.64,4.61,5.21,4.65],
-            [3.61,4.48,5.02,5.17,3.55],
-            [4.01,4.07,4.68,4.07,3.76]
+            [7.98744797707,7.95994615555,8.0069360733,8.01075410843,7.99107217789],
+            [4.4982790947,4.51797103882,4.53245615959,4.51872205734,4.49158000946],
+            [3.48803210258,3.5547580719,3.51397109032,3.51541280746,3.50235295296],
+            [3.0812599659,3.05026102066,3.07854914665,3.05468702316,3.05405092239],
         ],
         "cpython":[
-            [1.93,1.93,1.88,1.90,1.95],
-            [5.76,5.78,5.78,5.71,5.79],
-            [5.91,5.66,5.66,5.60,5.68],
-            [6.03,5.98,6.01,6.03,5.97]
+            [1.89,1.89,1.90,1.90,1.90],
+            [5.70,5.70,5.72,5.74,5.75],
+            [5.90,5.92,5.97,5.93,5.91],
+            [5.95,5.92,5.92,5.93,5.90],
         ],
         # "jython":[
         #     [1.76,1.84],
@@ -61,24 +63,24 @@
         #     [2.57,2.52,2.48]
         # ],
         "pypy-nojit":[
-            [6.23,6.41,6.27,6.23,6.29],
-            [10.3,10.5,10.4,10.5,10.3],
-            [11.4,11.4,11.3,11.3,11.5],
-            [12.0,12.3,12.3,12.1,12.1]
+            [6.18,6.17,6.17,6.18,6.19],
+            [9.94,9.96,9.96,9.93,9.93],
+            [10.36,10.33,10.38,10.37,10.40],
+            [10.53,10.52,10.53,10.53,10.54],
         ]}),
 
     ("skiplist (small)", {
         "pypy-stm-nojit":[
-            [5.80,5.91,6.10,5.71,5.58],
-            [3.71,3.42,3.73,3.60,3.54],
-            [3.22,2.95,3.25,3.61,3.03],
-            [3.50,3.25,3.68,3.87,3.27]
+            [5.3692650795,5.75404596329,5.80874490738,5.56507706642,5.54502797127],
+            [3.33223390579,3.43795180321,3.7308909893,3.6313188076,3.4803340435],
+            [2.90017795563,2.96001410484,2.98225808144,2.90836501122,3.08461618423],
+            [2.69811701775,2.71903181076,2.7594909668,2.6924469471,2.68277978897],
         ],
         "cpython":[
-            [3.3,3.1,3.3,3.2,3.3],
-            [4.9,5.2,5.2,5.1,5.2],
-            [5.0,5.4,5.3,5.3,5.4],
-            [5.1,5.4,5.3,5.3,5.4]
+            [3.18362903595,3.13687205315,3.09498882294,2.87599921227,3.094383955],
+            [4.9131629467,5.09300899506,4.8633351326,5.01421904564,5.00006604195],
+            [5.0695669651,5.18470811844,5.03273797035,5.17617797852,4.92464590073],
+            [5.08509016037,5.05335688591,5.1101269722,5.26950407028,5.11297392845],
         ],
         # "jython":[
         #     [1.38,1.33,1.47,1.40],
@@ -87,24 +89,24 @@
         #     [1.99,1.92,1.74,1.84]
         # ],
         "pypy-nojit":[
-            [4.01,4.10,4.11,3.88,3.97],
-            [5.92,5.84,5.74,6.16,5.76],
-            [6.67,6.42,6.51,6.48,6.48],
-            [6.50,6.59,6.93,6.61,6.56]
+            [3.99729990959,3.92795300484,3.92997407913,4.02246403694,4.16354703903],
+            [6.20531105995,6.0312640667,5.67126297951,5.88649582863,5.58283090591],
+            [6.22896409035,6.35634803772,6.38776803017,6.00280714035,6.2800180912],
+            [6.13741707802,6.11261510849,6.20782995224,6.05345606804,6.21988797188],
         ]}),
 
     ("threadworms (small)", {
         "pypy-stm-nojit":[
-            [4.71,4.67,4.69,4.71,4.69],
-            [2.61,2.55,2.53,2.52,2.56],
-            [2.01,1.86,1.88,1.93,2.31],
-            [2.14,2.02,2.46,2.06,1.69]
+            [4.66151094437,4.58688688278,4.66727614403,4.6772108078,4.6156001091],
+            [2.49641013145,2.50251197815,2.49980187416,2.49767017365,2.49619984627],
+            [1.84332799911,1.86481595039,1.85224509239,1.84722995758,1.86878705025],
+            [1.548361063,1.55502295494,1.54036188126,1.51436495781,1.55404090881],
         ],
         "cpython":[
-            [1.64,1.62,1.62,1.66,1.64],
-            [5.08,5.10,5.08,5.01,5.16],
-            [5.00,5.10,5.15,5.52,5.01],
-            [5.37,5.30,5.41,5.21,5.10]
+            [1.63531804085,1.63171005249,1.64426994324,1.63068985939,1.63233208656],
+            [5.11088013649,5.0750939846,5.07781815529,5.03861713409,5.14281582832],
+            [5.18783211708,5.15396308899,5.14551186562,5.12670898438,5.14967012405],
+            [5.2029311657,5.18416690826,5.16408801079,5.17987704277,5.16225814819],
         ],
         # "jython":[
         #     [2.73,2.38,2.63,2.4],
@@ -113,24 +115,44 @@
         #     [3.19,3.37,3.26,3.36]
         # ],
         "pypy-nojit":[
-            [4.02,4.03,4.01,4.05,4.05],
-            [7.21,7.23,7.30,7.12,7.21],
-            [8.05,8.03,8.08,8.12,8.02],
-            [8.54,8.56,8.61,8.91,8.80]
+            [3.96425199509,3.92935299873,3.9230401516,3.93678808212,3.9455499649],
+            [7.18407416344,7.18444395065,7.16915011406,7.18182110786,7.22779583931],
+            [7.66615414619,7.66010093689,7.72703194618,7.71287798882,7.72050714493],
+            [7.84829282761,7.84318208694,7.78388905525,7.74968695641,7.74719285965],
+        ]}),
+
+    ("miller-rabin (small)", {
+        "pypy-stm-nojit":[
+            [3.369349956512451, 3.3623909950256348, 3.3570539951324463, 3.35870099067688, 3.352569103240967],
+            [1.8622829914093018, 1.8384361267089844, 1.8307039737701416, 1.8440592288970947, 1.8353259563446045],
+            [1.4145839214324951, 1.3829829692840576, 1.3893311023712158, 1.4124789237976074, 1.3802859783172607],
+            [1.259462833404541, 1.2429590225219727, 1.246514081954956, 1.216398000717163, 1.2270379066467285]
+        ],
+        "cpython":[
+            [1.463728904724121, 1.4588379859924316, 1.4599599838256836, 1.454383134841919, 1.4613091945648193],
+            [1.9370648860931396, 1.9515810012817383, 1.9363758563995361, 1.9516470432281494, 1.9729619026184082],
+            [2.0382211208343506, 2.0417628288269043, 2.038292169570923, 2.033823013305664, 2.0392959117889404],
+            [2.0457639694213867, 2.0550150871276855, 2.045275926589966, 2.0547900199890137, 2.058414936065674]
+        ],
+        "pypy-nojit":[
+            [3.1500821113586426, 3.1333930492401123, 3.133725881576538, 3.1395609378814697, 3.137906074523926],
+            [5.383965015411377, 5.348900079727173, 5.329493999481201, 5.293528079986572, 5.336282014846802],
+            [5.570706129074097, 5.564241170883179, 5.5810630321502686, 5.539607048034668, 5.5388758182525635],
+            [5.5085608959198, 5.483498811721802, 5.5816099643707275, 5.592865943908691, 5.601343870162964]
         ]}),
 
     ("mandelbrot (small)", {
         "pypy-stm-nojit":[
-            [5.35,5.30,5.23,5.15,5.21],
-            [2.71,2.69,2.66,2.67,2.64],
-            [1.96,1.81,1.87,1.83,1.91],
-            [1.88,1.95,1.85,1.75,1.86]
+            [5.3069088459,5.2796959877,5.27015900612,5.3081278801,5.32982206345],
+            [2.67205810547,2.66844701767,2.66896700859,2.68082690239,2.6778409481],
+            [1.87407612801,1.89018201828,1.88588881493,1.87249279022,1.88197517395],
+            [1.50376915932,1.55750012398,1.49635004997,1.50658798218,1.5112760067],
         ],
         "cpython":[
-            [1.65,1.70,1.61,1.73,1.66],
-            [2.40,2.27,2.30,2.31,2.30],
-            [2.41,2.46,2.34,2.42,2.46],
-            [2.51,2.40,2.45,2.37,2.49]
+            [1.66689109802,1.70921182632,1.67385601997,1.74684906006,1.67685079575],
+            [2.22828507423,2.22786307335,2.21894907951,2.23693585396,2.23923707008],
+            [2.27540802956,2.28734898567,2.26518392563,2.2811088562,2.27695202827],
+            [2.28982901573,2.28482198715,2.29300618172,2.29116606712,2.28355097771],
         ],
         # "jython":[
         #     [5.56,5.61,5.59,5.55],
@@ -139,24 +161,24 @@
         #     [1.8,1.74,1.8,1.88]
         # ],
         "pypy-nojit":[
-            [3.54,3.33,3.39,3.38,3.34],
-            [4.43,4.43,4.47,4.47,4.46],
-            [4.14,3.62,4.07,4.20,3.79],
-            [3.88,3.83,3.82,3.79,3.88]
+            [3.37114810944,3.36375617981,3.36287212372,3.36206793785,3.36504197121],
+            [4.47998595238,4.47378611565,4.46991205215,4.47737216949,4.41863703728],
+            [4.3745610714,4.37568807602,4.37834095955,4.37904405594,4.38698601723],
+            [4.40002799034,4.40542793274,4.40231585503,4.40534210205,4.39605498314],
         ]}),
 
     ("raytrace (small)", {
         "pypy-stm-nojit":[
-            [8.3, 8.04,7.99,7.91,8.03,],
-            [4.33,4.21,4.28,4.23,4.24,],
-            [3.74,3.61,3.09,4.18,3.01,],
-            [3.08,2.89,2.75,3.06,2.98,]
+            [8.09555792809,8.03761792183,8.07105588913,8.08723092079,8.02405285835],
+            [4.23407101631,4.20152997971,4.19831204414,4.20036005974,4.19185209274],
+            [2.99346899986,3.01209020615,3.02385997772,2.99872112274,3.01878595352],
+            [2.58209013939,2.62102484703,2.58993005753,2.59897303581,2.5549788475],
         ],
         "cpython":[
-            [2.5,2.55,2.51,2.54,2.52,],
-            [2.7,2.67,2.67,2.69,2.71,],
-            [2.75,2.77,2.75,2.80,2.76,],
-            [2.84,2.83,2.85,2.86,2.83,]
+            [2.52900099754,2.52002096176,2.53882884979,2.53405308723,2.52506089211],
+            [2.64264392853,2.62728977203,2.68032217026,2.6406929493,2.651679039],
+            [2.74740791321,2.75495100021,2.73957586288,2.74933600426,2.72902297974],
+            [2.85847210884,2.85967087746,2.87045097351,2.87352895737,2.87047505379],
         ],
         # "jython":[
         #     [2.95,2.95,2.96],
@@ -165,24 +187,24 @@
         #     [1.09,0.9,0.97,0.99,1.03]
         # ],
         "pypy-nojit":[
-            [5.41,5.36,5.34,5.31,5.38],
-            [6.66,6.63,6.61,6.51,6.60],
-            [6.34,6.29,6.22,6.32,6.31],
-            [5.91,5.72,5.88,5.87,5.78]
+            [5.2403049469,5.23123502731,5.23440098763,5.25973105431,5.22721982002],
+            [6.54222011566,6.54369497299,6.55081796646,6.5521800518,6.56022405624],
+            [6.10841608047,6.15412402153,6.15307998657,6.16904401779,6.13451099396],
+            [5.46543121338,5.47703313828,5.47254896164,5.49223995209,5.50018310547],
         ]}),
 
     ("richards (small)", {
         "pypy-stm-nojit":[
-            [10.1,10.24,10.18,10.20,10.32],
-            [5.71,5.79,5.73,5.75,5.75],
-            [5.41,4.28,5.22,4.96,5.51],
-            [4.61,4.62,4.51,4.49,5.08]
+            [9.90,9.89,9.85,9.92,9.95],
+            [5.50,5.55,5.52,5.48,5.52],
+            [4.06,4.09,4.09,4.09,4.08],
+            [3.63,3.61,3.54,3.51,3.54],
         ],
         "cpython":[
             [2.51,2.45,2.55,2.51,2.50],
             [3.87,3.71,3.88,3.81,3.75],
-            [4.02,4.08,4.10,4.02,3.98],
-            [4.13,4.01,4.15,3.99,4.12]
+            [3.72,3.74,3.71,3.70,3.72],
+            [3.76,3.78,3.79,3.80,3.76],
         ],
         # "jython":[
         #     [3.39,3.31,3.7],
@@ -193,9 +215,30 @@
         "pypy-nojit":[
             [5.95,6.02,5.99,5.92,6.03],
             [7.88,7.78,7.77,7.69,7.79],
-            [7.01,7.02,7.17,7.05,7.21],
-            [6.66,6.71,6.58,6.65,6.56]
-        ]})
+            [7.66,7.66,7.81,7.75,7.53],
+            [7.89,7.93,7.81,7.69,7.80]
+        ]}),
+
+    ("mersenne (small)", {
+        "pypy-stm-nojit":[
+            [3.6719789505004883, 3.6668028831481934, 3.664036989212036, 3.6665987968444824, 3.6641900539398193],
+            [2.137367010116577, 1.9911909103393555, 1.9913787841796875, 1.9875690937042236, 1.988551139831543],
+            [2.0355780124664307, 2.0366389751434326, 2.029282808303833, 2.0356709957122803, 2.0340609550476074],
+            [1.9997708797454834, 1.996995210647583, 2.0678999423980713, 2.075084924697876, 1.994607925415039]
+        ],
+        "cpython":[
+            [3.263484001159668, 3.2587788105010986, 3.25673508644104, 3.2573680877685547, 3.255321979522705],
+            [3.2739717960357666, 3.274899959564209, 3.293348789215088, 3.2946629524230957, 3.29618501663208],
+            [3.3265891075134277, 3.2955169677734375, 3.2899580001831055, 3.305911064147949, 3.2877209186553955],
+            [3.2929179668426514, 3.2984700202941895, 3.2903239727020264, 3.301953077316284, 3.2956490516662598]
+        ],
+        "pypy-nojit":[
+            [2.2521681785583496, 2.2531819343566895, 2.252506971359253, 2.2531309127807617, 2.256279945373535],
+            [2.287511110305786, 2.284902811050415, 2.28535795211792, 2.2856361865997314, 2.2816338539123535],
+            [2.328660011291504, 2.3119280338287354, 2.330618143081665, 2.330143928527832, 2.328179121017456],
+            [2.3237390518188477, 2.3256571292877197, 2.318053960800171, 2.317232131958008, 2.3278181552886963]
+        ]}),
+
 ])
 
 def geom_mean(xs):
@@ -228,7 +271,7 @@
     global fig
 
     print "Draw..."
-    legend = plot_speedups(plt, 2, 3, benchs, interps_styles)
+    legend = plot_speedups(plt, 2, 4, benchs, interps_styles)
 
     #axs[0].set_ylim(0, len(x))
     #ax.set_yticks([r+0.5 for r in range(len(logs))])
@@ -256,7 +299,7 @@
 if __name__ == "__main__":
     import argparse
     parser = argparse.ArgumentParser(description='Plot stm log files')
-    parser.add_argument('--figure-size', default='7x8',
+    parser.add_argument('--figure-size', default='7x10',
                         help='set figure size in inches: format=6x4')
     parser.add_argument('--font-size', default='10.0',
                         help='set font size in pts: 10.0')
diff --git a/talk/dls2014/paper/plots/plot_scaling.py b/talk/dls2014/paper/plots/plot_scaling.py
--- a/talk/dls2014/paper/plots/plot_scaling.py
+++ b/talk/dls2014/paper/plots/plot_scaling.py
@@ -1,7 +1,7 @@
 #!/usr/bin/python
 
 # obtained with time on
-#   pypy-c --jit off bench_scaling.py [1-4]
+#   pypy-c-paper-nojit bench_scaling.py [1-4]
 
 
 import matplotlib
@@ -20,10 +20,12 @@
 # import pprint - slow as hell
 
 xs = range(1,5)
-ys = [[1.78,1.79,1.75,1.81,1.76],
-      [1.82,1.82,1.80,1.80,1.8],
-      [1.88,1.97,1.89,1.90,1.94],
-      [1.96,1.99,1.87,2.00,1.97,2.09,1.98,2.12]]
+ys = [
+    [1.77,1.75,1.75,1.74,1.75],
+    [1.75,1.74,1.75,1.76,1.75],
+    [1.80,1.92,1.87,1.88,1.84],
+    [1.90,1.92,1.94,1.88,1.92],
+]
 
 
 
diff --git a/talk/dls2014/paper/plots/performance_nojit.pdf b/talk/dls2014/paper/plots/performance_nojit.pdf
index d26324f323c84ea0c8b4fab8a12a161d3e3edcc3..f189a9c696c64c18e3fc1ca70ef5f5eba1055c5c
GIT binary patch

[cut]

diff --git a/talk/dls2014/paper/plots/plot_performance.py b/talk/dls2014/paper/plots/plot_performance.py
--- a/talk/dls2014/paper/plots/plot_performance.py
+++ b/talk/dls2014/paper/plots/plot_performance.py
@@ -4,13 +4,14 @@
 
 # for now: avg & stddev of the best
 
-#    pypy-c-paper-jit bench.py -k5 raytrace/raytrace.py 1-4
-#    pypy-c-paper-jit bench.py -k5 btree/btree.py 1-4
-#    pypy-c-paper-jit bench.py -k5 skiplist/skiplist.py 1-4
-#    pypy-c-paper-jit bench.py -k5 threadworms/threadworms.py 1-4
-#    pypy-c-paper-jit bench.py -k5 mandelbrot/mandelbrot.py 1-4 64
-#    pypy-c-paper-jit multithread-richards.py 10000 1-4 # report runtime
-
+#    pypy-c-paper-jit bench.py -k7 raytrace/raytrace.py 1-4
+#    pypy-c-paper-jit bench.py -k7 btree/btree.py 1-4
+#    pypy-c-paper-jit bench.py -k7 skiplist/skiplist.py 1-4
+#    pypy-c-paper-jit bench.py -k7 threadworms/threadworms.py 1-4
+#    pypy-c-paper-jit bench.py -k7 mandelbrot/mandelbrot.py 1-4 64
+#    pypy-c-paper-jit multithread-richards.py 3000 1-4 # report runtime
+# miller_rabin: pypy-c-paper-jit bench.py -k7 primes/primes.py 1-4
+# mersenne: pypy-c-paper-jit bench.py -k7 mersenne/mersenne.py 1-4
 
 
 import matplotlib
@@ -42,52 +43,66 @@
 benchs = OrderedDict([
     ("btree (large)", {
         "pypy-stm-jit":[
-            [1.68,1.74,1.73,1.67,1.68,1.65],
-            [1.35,1.54,1.52,1.28,1.31,1.28],
-            [1.39,1.50,1.44,1.47,1.41,1.37],
-            [1.66,1.67,1.68,1.66,1.71,1.71]
+            [1.67845606804,1.65006303787,1.66974020004,1.63858819008,1.66356801987],
+            [1.33803701401,1.32292485237,1.31796693802,1.35001111031,1.31932878494],
+            [1.36447811127,1.36002612114,1.36561393738,1.33688187599,1.36755800247],
+            [1.57205200195,1.57919001579,1.56078600883,1.5807390213,1.53369808197],
         ],
         "pypy-jit":[
-            [1.61,1.62,1.61,1.59,1.59],
-            [3.31,3.33,3.29,3.27,3.35],
-            [5.11,5.20,5.07,5.00,5.25],
-            [5.85,6.02,6.14,6.05,5.91]
+            [1.55986404419,1.56078219414,1.55183196068,1.56036901474,1.55763506889],
+            [3.08302307129,3.07977199554,3.19185519218,3.08162689209,3.15804696083],
+            [4.98545002937,5.04515981674,5.00658583641,5.05858302116,5.0690600872],
+            [5.81887507439,5.83665108681,5.82539606094,5.85461807251,5.80481886864],
         ]}),
 
     ("skiplist (large)", {
         "pypy-stm-jit":[
-            [2.91,2.88,2.92,2.92,2.96],
-            [3.05,2.90,2.89,2.93,2.94],
-            [3.48,3.21,3.18,3.33,3.15],
-            [3.87,3.69,3.78,3.81,3.66]
+            [2.8317830562591553, 2.9466500282287598, 2.777143955230713, 2.9067370891571045, 2.868476152420044],
+            [2.9228100776672363, 2.9347541332244873, 2.9178760051727295, 2.9834980964660645, 2.957442045211792],
+            [3.15556001663208, 3.139164924621582, 3.1457889080047607, 3.2395389080047607, 3.176427125930786],
+            [3.60280704498291, 3.591495990753174, 3.5838911533355713, 3.6133289337158203, 3.5673019886016846],
         ],
         "pypy-jit":[
-            [2.14,2.17,2.31,2.24,2.34],
-            [4.54,4.61,4.69,4.63,4.57],
-            [6.29,6.14,6.25,6.16,6.21],
-            [6.58,6.62,6.61,6.70,6.83]
+            [2.1221060752868652, 2.1250720024108887, 2.1107590198516846, 2.131819009780884, 2.1142380237579346],
+            [4.392746210098267, 4.336360216140747, 4.410413980484009, 4.3028059005737305, 4.448081970214844],
+            [6.0925071239471436, 6.012751817703247, 5.994383811950684, 5.925648927688599, 6.02409815788269],
+            [6.677470922470093, 6.746111154556274, 6.772925138473511, 6.698845148086548, 6.861325025558472],
         ]}),
 
     ("threadworms (large)", {
         "pypy-stm-jit":[
-            [4.23,4.33,4.46,4.47,4.50],
-            [3.4,3.34,3.39,3.32,3.02,3.13],
-            [3.16,2.96,3.5,2.9,3.3],
-            [3.4, 3.3,3.32,3.86,3.4]
+            [4.517525911331177, 4.548923015594482, 4.584195137023926, 4.576831102371216, 4.5510969161987305],
+            [3.2610208988189697, 3.287199020385742, 3.2835729122161865, 2.83652400970459, 3.355794906616211],
+            [2.552337169647217, 3.3851380348205566, 3.3292200565338135, 2.512721061706543, 3.395833969116211],
+            [3.0494518280029297, 3.304857015609741, 3.465865135192871, 3.483139991760254, 2.9930028915405273],
         ],
         "pypy-jit":[
-            [4.14,4.20,4.24,4.25,4.13],
-            [12.5,11.4,12.3,11.9,11.7],
+            [4.137892007827759, 4.017345190048218, 4.04946494102478, 4.033931016921997, 4.049654006958008],
+            [12.235527038574219, 12.323483943939209, 12.391777992248535, 12.369697093963623, 12.642794132232666],
             [16.1,15.8,15.7,16.2,15.9],
             [20.3,19.8,18.9,19.7,19.5]
         ]}),
 
+    ("miller-rabin (large)", {
+        "pypy-stm-jit":[
+            [2.469092845916748, 2.465752124786377, 2.5735549926757812, 2.424694061279297, 2.4528331756591797],
+            [1.6964740753173828, 1.7057690620422363, 1.687267780303955, 1.6836810111999512, 1.7357711791992188],
+            [1.9504740238189697, 1.9206480979919434, 1.959285020828247, 1.9674179553985596, 1.9120190143585205],
+            [2.1957740783691406, 2.259826898574829, 2.246433973312378, 2.158545970916748, 2.1627681255340576],
+        ],
+        "pypy-jit":[
+            [2.161806106567383, 2.1457087993621826, 2.144040107727051, 2.151695966720581, 2.1421849727630615],
+            [3.4412081241607666, 3.4092049598693848, 3.4685871601104736, 3.388669013977051, 3.453207015991211],
+            [4.572340965270996, 4.519361972808838, 4.503000020980835, 4.507853984832764, 4.442840814590454],
+            [5.5019919872283936, 5.51775598526001, 5.487698078155518, 5.485651969909668, 5.482367038726807],
+        ]}),
+
     ("mandelbrot (large)", {
         "pypy-stm-jit":[
-            [17.87,17.88,17.88,17.63,17.75],
-            [9.18,9.31,9.28,9.20,9.10,9.25],
-            [7.75,7.8,7.81,7.7,7.09,7.59,7.43],
-            [6.8,6.55,6.9,6.7,7.29,6.88,7.1]
+            [17.430854082107544, 17.26646614074707, 17.176318883895874, 17.15704083442688, 17.212379217147827],
+            [9.08885383605957, 9.0710289478302, 9.040630102157593, 9.0260329246521, 9.00651502609253],
+            [6.48170804977417, 6.4656219482421875, 6.51883602142334, 6.484840154647827, 6.444514036178589],
+            [5.4356160163879395, 5.4222729206085205, 5.4224090576171875, 5.452478885650635, 5.4159040451049805],
         ],
         "pypy-jit":[
             [13.5,13.7,13.6,13.7,14.0],
@@ -98,31 +113,47 @@
 
     ("raytrace (large)", {
         "pypy-stm-jit":[
-            [3.91,3.87,3.88,3.92,3.98,3.95],
-            [2.53,2.52,2.46,2.42,2.44,2.43],
-            [2.23,2.17,2.12,2.16,2.30,2.35],
-            [2.46,2.44,2.45,2.52,2.59,2.51]
+            [3.9185469150543213, 3.8989100456237793, 3.8274168968200684, 3.844446897506714, 3.8334569931030273],
+            [2.2376699447631836, 2.236940860748291, 2.1736011505126953, 2.1718149185180664, 2.1718950271606445],
+            [1.8365809917449951, 1.83445405960083, 1.8318328857421875, 1.830247163772583, 1.8350648880004883],
+            [1.7387700080871582, 1.7485370635986328, 1.7356500625610352, 1.7735240459442139, 1.7386369705200195],
         ],
         "pypy-jit":[
-            [1.60,1.59,1.61,1.62,1.66,1.59],
-            [3.02,3.01,3.15,3.21,2.91,3.19],
-            [3.33,3.33,3.34,3.30,3.21,3.47],
-            [3.57,3.67,3.34,3.48,3.46,3.61]
+            [1.5851430892944336, 1.5589039325714111, 1.5606789588928223, 1.5591561794281006, 1.5676798820495605],
+            [2.041408061981201, 2.042022943496704, 2.018625020980835, 2.0331828594207764, 1.9610838890075684],
+            [3.759972095489502, 3.7670998573303223, 3.787578821182251, 3.7681820392608643, 3.75722599029541],
+            [4.019146919250488, 4.016950845718384, 4.092247009277344, 4.044332981109619, 4.066432952880859],
         ]}),
 
     ("richards (large)", {
         "pypy-stm-jit":[
-            [63.4,61.3,62.4,71.2,63.9],
-            [33.1,38.1,32.9,35.3,35.7],
-            [24.9,36.1,24.9,33.4,25.4],
-            [27.1,39.0,63.5,45.5,21.1]
+            [17.73,17.73,17.74,17.72,17.73],
+            [10.41,10.43,10.43,10.39,10.41],
+            [9.73,9.77,9.81,9.74,9.67],
+            [9.95,10.00,9.95,10.00,9.94],
         ],
         "pypy-jit":[
-            [30.7,30.6,31.2,30.5,29.1],
-            [31.4,28.5,31.5,29.7,32.8],
-            [33.0,29.5,34.1,32.0,33.4],
-            [32.0,32.4,34.6,32.6,31.4]
+            [8.87,8.89,8.89,8.87,8.90],
+            [9.79,9.79,9.81,9.75,9.80],
+            [9.95,9.95,9.95,9.98,9.93],
+            [9.04,9.06,9.01,9.11,9.21]
+        ]}),
+
+    ("mersenne (large)", {
+        "pypy-stm-jit":[
+            [9.245907068252563, 9.243618965148926, 9.244323968887329, 9.241997957229614, 9.242669820785522],
+            [4.897014141082764, 4.882230043411255, 4.881627082824707, 4.883110046386719, 4.883028030395508],
+            [3.603656053543091, 3.6193759441375732, 3.6500911712646484, 3.613867998123169, 3.607400894165039],
+            [3.6181468963623047, 3.716840982437134, 3.6233408451080322, 3.7763969898223877, 3.4737911224365234],
+
+        ],
+        "pypy-jit":[
+            [5.46359395980835, 5.463193893432617, 5.461122035980225, 5.4631431102752686, 5.46463680267334],
+            [5.476777076721191, 5.47367787361145, 5.4741599559783936, 5.473356008529663, 5.47412896156311],
+            [5.497221946716309, 5.484626054763794, 5.478212833404541, 5.484951972961426, 5.490041017532349],
+            [5.511621952056885, 5.505235910415649, 5.497171878814697, 5.482274055480957, 5.495197772979736],
         ]})
+
 ])
 
 def geom_mean(xs):
@@ -196,7 +227,7 @@
     global fig
 
     print "Draw..."
-    legend = plot_speedups(plt, 2, 3, benchs, interps_styles)
+    legend = plot_speedups(plt, 2, 4, benchs, interps_styles)
 
     #axs[0].set_ylim(0, len(x))
     #ax.set_yticks([r+0.5 for r in range(len(logs))])
@@ -224,7 +255,7 @@
 if __name__ == "__main__":
     import argparse
     parser = argparse.ArgumentParser(description='Plot stm log files')
-    parser.add_argument('--figure-size', default='7x8',
+    parser.add_argument('--figure-size', default='7x10',
                         help='set figure size in inches: format=6x4')
     parser.add_argument('--font-size', default='10.0',
                         help='set font size in pts: 10.0')
diff --git a/talk/dls2014/paper/plots/scaling.pdf b/talk/dls2014/paper/plots/scaling.pdf
index 091ef98afae2c580360a3ee1de6d388d10ef8f92..a6e66ba747ea2c961db81964298618003d0bc34b
GIT binary patch

[cut]



More information about the pypy-commit mailing list